// ============================================================================
// Project:	Deductive Database
// Filename:	bench.cpp
// Purpose:	Superclass for Standard Benchmark with load() and eval()
// Last Change:	17.05.2016
// Language:	C++
// EMail:	brass@informatik.uni-halle.de
// WWW:		http://www.informatik.uni-halle.de/~brass/
// Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
// Copyright:	(c) 2016 by Stefan Brass
// License:	See file "LICENSE" for copying conditions.
// Note:	There is no warranty at all - this code may contain bugs.
// ============================================================================


//=============================================================================
// Interface:
//=============================================================================

#include "ver.h"
#include "str.h"
#ifdef	VER_DUMP
#include "err.h"
#endif
#include "check.h"

#include "bench.h"


//=============================================================================
// Constructor and Destructor:
//=============================================================================

//-----------------------------------------------------------------------------
// Constructor:
//-----------------------------------------------------------------------------

bench_c::bench_c()
{
	// Set Magic number:
	CHECK_CODE(Magic = BENCH_MAGIC);
}

//-----------------------------------------------------------------------------
// Destructor:
//-----------------------------------------------------------------------------

bench_c::~bench_c()
{
	// Check this object:
	CHECK_VALID("bench_c::destructor");

	// Make this object invalid:
	CHECK_CODE(Magic = 0);
}


//=============================================================================
// Debugging Support:
//=============================================================================

//-----------------------------------------------------------------------------
// check: Check the integrity of this object, return error message or NULL.
//-----------------------------------------------------------------------------

#ifdef	VER_DEBUG
str_t	bench_c::check() const
{
	// Check magic number:
	if(Magic != BENCH_MAGIC)
		return "wrong magic number";

	// Ok:
	return 0;
}
#endif


//-----------------------------------------------------------------------------
// dump: Show data structure.
//-----------------------------------------------------------------------------

#ifdef	VER_DUMP
void	bench_c::dump(str_t headline) const
{
	// Insert default headline:
	if(headline == STR_NULL)
		headline = "Standard Benchmark Object";

	// This class has no attributes, but we show the subclass name.
	err_c::dump_str("Name:        '");
	err_c::dump_str(this->name());
	err_c::dump_str("'");
	err_c::dump_nl();


	// Done:
	err_c::dump_end();
}
#endif

